Installation
============
This is the installation guide for the project.


Prerequisites
-------------

adam requires python 3.7 or later.


🐍 Conda installation
---------------------

We suggest to install adam using `conda <https://anaconda.org/>`_:

.. code-block:: bash

    conda install adam-robotics -c conda-forge

📦 Pip installation
--------------------

You can also install adam using `pip <https://pypi.org/project/pip/>`_:

.. code-block:: bash

    pip install adam-robotics

If you want to install all the dependencies install ``adam-robotics[all]``.

.. note::

    If the GPU support for ``JAX`` is needed, follow the instructions in the `Jax documentation <https://jax.readthedocs.io/en/latest/installation.html#conda-community-supported>`_.
